GaussianCovCost — skchange

Skip to main content
`Ctrl`+`K`

# GaussianCovCost

GaussianCovCost(param: tuple[_SupportsArray[dtype[Any]] | _NestedSequence[_SupportsArray[dtype[Any]]] | bool | int | float | complex | str | bytes | _NestedSequence[bool | int | float | complex | str | bytes] | Number, _SupportsArray[dtype[Any]] | _NestedSequence[_SupportsArray[dtype[Any]]] | bool | int | float | complex | str | bytes | _NestedSequence[bool | int | float | complex | str | bytes] | Number] | None = None)

  Multivariate Gaussian likelihood cost.

  Parameters:
    param2-tuple of float or np.ndarray, or None (default=None)

      Fixed mean and covariance matrix for the cost calculation. If None, the maximum likelihood estimates are used.